@@ -2,14 +2,12 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 12.2.1-19-s
-description: >
-    A direct eval assigning into 'arguments' throws SyntaxError in
-    strict mode
+es5id: 12.2.1-12-s
+description: arguments as local var identifier throws SyntaxError in strict mode
 flags: [onlyStrict]
 ---*/
 
 
 assert.throws(SyntaxError, function() {
-    eval('arguments = 42;');
+    eval('function foo() { var arguments;}');
 });
