@@ -5,10 +5,10 @@
 info: |
     No matter how control leaves the embedded 'Statement',
     the scope chain is always restored to its former state
-es5id: 12.10_A3.10_T4
+es5id: 12.10_A3.5_T4
 description: >
-    Using iteration statement within "with" statement, leading
-    completion be break
+    Using "with" statement within "for-in" statement, leading to
+    completion by break
 flags: [noStrict]
 ---*/
 
@@ -22,11 +22,11 @@ var myObj = {
     valueOf : function(){return 'obj_valueOf';}
 }
 
-with(myObj){
-    do{
+for(var prop in myObj){
+    with(myObj){
         p1 = 'x1';
         break;
-    } while(false);
+    }
 }
 
 //////////////////////////////////////////////////////////////////////////////
